@@ -2,10 +2,10 @@ autoreconf
 
 ./configure \
   $PKGCFG \
-  $CROSSCFG \
+  --host=i686-w64-mingw32.static \
   --with-ptw32=$PREFIX/i686-w64-mingw32.static \
   --enable-static \
-  PTW32_LIBS="-lpthread -lpcreposix -lpcre -lregex" \
+  PTW32_LIBS="-lpthread -lpcreposix -lpcre" \
   FLTK_CONFIG=$PREFIX/bin/i686-w64-mingw32.static-fltk-config
 
 make
