@@ -10,7 +10,7 @@ static const char *copyright[] = {
 	" FLAMP "  VERSION, // flamp.cxx
 	"",
 	" Author(s):",
-	"    Robert Stiles, KK5VD, Copyright (C) 2013, 2014, 2015",
+	"    Robert Stiles, KK5VD, Copyright (C) 2013, 2014, 2015, 2023, 2024",
 	"    Dave Freese, W1HKJ, Copyright (C) 2012-2015, 2023",
 	"",
 	" This is free software; you can redistribute it and/or modify",
@@ -725,20 +725,22 @@ void addfile(ScriptParsing *sp, SCRIPT_COMMANDS *sc)
 
 	FILE *dfile = fopen(xmt_fname.c_str(), "rb");
 	if (!dfile) {
-		LOG_ERROR("could not open read/binary %s", xmt_fname.c_str());
-		exit (1);
+		LOG_INFO("Could not open/locate file %s", xmt_fname.c_str());
+		return;
 	}
 	fseek(dfile, 0, SEEK_END);
 	size_t fsize = ftell(dfile);
 	if (fsize <= 0) {
-		LOG_ERROR("%s", "fsize error");
+		fclose(dfile);
+		LOG_INFO("%s", "fsize error");
 		return;
 	}
 	fseek(dfile, 0, SEEK_SET);
 	tx_buffer.resize(fsize);
 	size_t r = fread((void *)tx_buffer.c_str(), 1, fsize, dfile);
 	if (r != fsize) {
-		LOG_ERROR("%s", "read error");
+	    fclose(dfile);
+		LOG_INFO("%s", "read error");
 		return;
 	}
 
@@ -851,20 +853,22 @@ void addfile(std::string xmtfname, void *rx, bool useCompression, \
 
 	FILE *dfile = fopen(xmt_fname.c_str(), "rb");
 	if (!dfile) {
-		LOG_ERROR("could not open read/binary %s", xmt_fname.c_str());
-		exit (1);
+		LOG_INFO("Could not open/locate file %s", xmt_fname.c_str());
+		return;
 	}
 	fseek(dfile, 0, SEEK_END);
 	size_t fsize = ftell(dfile);
 	if (fsize <= 0) {
-		LOG_ERROR("%s", "fsize error");
+		LOG_INFO("%s", "fsize error");
+		fclose(dfile);
 		return;
 	}
 	fseek(dfile, 0, SEEK_SET);
 	tx_buffer.resize(fsize);
 	size_t r = fread((void *)tx_buffer.c_str(), 1, fsize, dfile);
 	if (r != fsize) {
-		LOG_ERROR("%s", "read error");
+		LOG_INFO("%s", "read error");
+		fclose(dfile);
 		return;
 	}
 
@@ -1587,7 +1591,7 @@ void send_relay_data(void)
 	missing_blocks.clear();
 	missing_blocks.assign(txt_relay_selected_blocks->value());
 
-	if(progStatus.use_txrx_interval || progStatus.use_header_modem) {
+	if(progStatus.use_txrx_interval) {
 		results = amp->tx_relay_vector(progStatus.my_call, missing_blocks);
 		if(results < 1) return;
 		relay_data.header = amp->xmt_vector_header();
