@@ -40,7 +40,7 @@
 #define PROG_CRC_FLAG 8
 
 #define CMD_FLAG   0x1
-#define flamp_FLAG 0x2
+#define FLAMP_FLAG 0x2
 
 #define RX_AMP 0x1
 #define TX_AMP 0x2
@@ -78,7 +78,7 @@ typedef struct relay_data {
 
 class cAmp {
 public:
-	enum { _FILE, _ID, _DTTM, _SIZE, _DESC, _DATA, _PROG, _CNTL };
+	enum { _FILE = 0, _ID, _DTTM, _SIZE, _DESC, _DATA, _PROG, _CNTL }; // Do not alter
 	typedef std::map<int, std::string> AMPmap;
 	cAmp(class cAmp *src_amp);
 
@@ -361,7 +361,7 @@ public:
 	std::string rx_report(void);
 	std::string rx_stats(void);
 	std::string rx_time_stamp() { return rxdttm; }
-	std::string tx_relay_string(std::string callfrom, std::string missig_blocks);
+	std::string tx_relay_string(std::string callfrom, std::string missig_blocks, bool filesave_flag);
 
 	void append_report(std::string s);
 	void rx_add_data(std::string data);
