@@ -4,7 +4,7 @@
 //
 // Author(s):
 // 	Dave Freese, W1HKJ Copyright (C) 2010
-//	Robert Stiles, KK5VD Copyright (C) 2013
+//	Robert Stiles, KK5VD Copyright (C) 2013, 2023
 //
 // This file is part of FLAMP.
 //
@@ -28,7 +28,6 @@
 
 #include <string>
 
-
 struct status {
 	int		mainX;
 	int		mainY;
@@ -103,6 +102,12 @@ struct status {
 
 	bool auto_rx_save;
 	bool auto_rx_save_local_time;
+	bool relay_retain_data;
+
+	int tab_saved_state;
+
+	int repeat_relay_data;
+	int repeat_relay_header;
 
 	void saveLastState();
 	void loadLastState();
