@@ -3,7 +3,7 @@
 //
 //  Author(s):
 //	Dave Freese, W1HKJ, Copyright (C) 2010, 2011, 2012, 2013
-//	Robert Stiles, KK5VD, Copyright (C) 2014
+//	Robert Stiles, KK5VD, Copyright (C) 2014, 2024
 //
 // This file is part of FLAMP.
 //
@@ -426,7 +426,7 @@ void transmit_relay(RELAY_DATA *rd)
 	transmit_stop  = false;
 	transmit_queue = false;
 
-	if(progStatus.use_txrx_interval || progStatus.use_header_modem)
+	if(progStatus.use_txrx_interval)
 		run_in_thread(transmit_relay_interval, TX_SEGMENTED, false, false, rd);
 	else
 		run_in_thread(transmit_serial_relay, 0, false, false, rd);
@@ -822,11 +822,7 @@ void * transmit_relay_interval(void * ptr)
 	thread_ptr->thread_running = 1;
 	thread_ptr->exit_thread = 0;
 	pthread_mutex_unlock(&thread_ptr->mutex);
-
-	if(progStatus.use_header_modem) {
-		turn_rsid_on();
-	}
-
+	
 	relay_data = (RELAY_DATA *) thread_ptr->data;
 
 	if(!relay_data)
@@ -862,31 +858,14 @@ void * transmit_relay_interval(void * ptr)
 
 	LOG_DEBUG("vector_header_count = %d", vector_header_count);
 
-	if(progStatus.use_header_modem) {
-		if(vector_header_count > 0) {
-			LOG_DEBUG("Header Modem Sent to FLDGI. (%s)", g_header_modem.c_str());
-			send_new_modem(thread_ptr->header_modem);
+	if(vector_header_count > 0)
+		send_vector_to_fldigi(thread_ptr, thread_ptr->modem, tail, vector_header_data, thread_ptr->mode, tx);
 
-			if(!send_vector_to_fldigi(thread_ptr, thread_ptr->header_modem, tail, vector_header_data, thread_ptr->mode, tx)) {
-				delete tx;
-				return run_in_thread_destroy(thread_ptr, 3, &in_use);
-			}
-		}
-	}
-	
 	wait_seconds(1, 100);
 
-	// Data section
-	if(progStatus.use_header_modem || progStatus.fldigi_xmt_mode_change) {
-		send_new_modem(thread_ptr->modem);
-	}
-
-	vector_data = relay_data->data;
-	vector_data_count = vector_data.size();
-
 	LOG_DEBUG("vector_data_count = %d", vector_data_count);
 
-	if(vector_data_count)
+	if(vector_data_count > 0)
 		send_vector_to_fldigi(thread_ptr, thread_ptr->modem, tail, vector_data, thread_ptr->mode, tx);
 
 	event_bail_flag = false;
