@@ -38,6 +38,7 @@
 
 #include "flamp.h"
 #include "flamp_dialog.h"
+#include "dialogs.h"
 #include "xml_io.h"
 #include "XmlRpc.h"
 #include "status.h"
@@ -46,20 +47,18 @@
 
 using XmlRpc::XmlRpcValue;
 
-#define DEFAULT_XMLRPC_TIMEOUT 15.0
-#define INIT_XMLRPC_TIMEOUT 5.0
-
 double xmlrpc_timeout = INIT_XMLRPC_TIMEOUT;
 
 // these are get only
 static const char* modem_get_name		     = "modem.get_name";
-static const char* modem_get_names		     = "modem.get_names";
+static const char* modem_get_io_names	     = "modem.get_io_names";
 
 // these are set only
 static const char* modem_set_by_name	     = "modem.set_by_name";
 static const char* text_clear_tx		     = "text.clear_tx";
 static const char* text_add_tx			     = "text.add_tx";
 static const char* text_clear_rx		     = "text.clear_rx";
+static const char* fldigi_get_version		 = "fldigi.version";
 static const char* main_get_trx_state	     = "main.get_trx_state";
 static const char* main_tx				     = "main.tx";
 static const char* main_tune			     = "main.tune";
@@ -74,7 +73,7 @@ static const char* io_in_use                 = "io.in_use";
 static const char* io_enable_arq             = "io.enable_arq";
 static const char* io_enable_kiss            = "io.enable_kiss";
 
-static XmlRpc::XmlRpcClient* client;
+static XmlRpc::XmlRpcClient* client = 0;
 
 #define XMLRPC_UPDATE_INTERVAL  200
 #define XMLRPC_UPDATE_AFTER_WRITE 1000
@@ -82,6 +81,10 @@ static XmlRpc::XmlRpcClient* client;
 
 extern int errno;
 
+size_t fldigi_state = FLDIGI_OFFLINE;
+static bool modem_list_received = false;
+
+
 //=====================================================================
 // socket ops
 //=====================================================================
@@ -91,7 +94,7 @@ std::string xmlcall = "";
 
 void open_xmlrpc()
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 
 	std::string addr;
 	std::string port;
@@ -112,19 +115,15 @@ void open_xmlrpc()
 
 	client = new XmlRpc::XmlRpcClient( addr.c_str(), server_port );
 
-	pthread_mutex_unlock(&mutex_xmlrpc);
-
 	//	XmlRpc::setVerbosity(5); // 0...5
 }
 
 void close_xmlrpc()
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 
 	delete client;
 	client = NULL;
-
-	pthread_mutex_unlock(&mutex_xmlrpc);
 }
 
 static inline void execute(const char* name, const XmlRpcValue& param, XmlRpcValue& result)
@@ -144,10 +143,10 @@ static inline void execute(const char* name, const XmlRpcValue& param, XmlRpcVal
 
 void set_xmlrpc_timeout(double value)
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
+
 	if(value < DEFAULT_XMLRPC_TIMEOUT) return;
 	xmlrpc_timeout = value;
-	pthread_mutex_unlock(&mutex_xmlrpc);
 }
 
 void set_xmlrpc_timeout_default(void)
@@ -163,9 +162,7 @@ void set_xmlrpc_timeout_default(void)
 
 void send_new_modem(std::string modem)
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
-
-	//g_modem.assign(modem);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 
 	try {
 		XmlRpcValue mode(modem), res;
@@ -173,13 +170,20 @@ void send_new_modem(std::string modem)
 	} catch (const XmlRpc::XmlRpcException& e) {
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
+	
 	update_interval = XMLRPC_UPDATE_AFTER_WRITE;
-	pthread_mutex_unlock(&mutex_xmlrpc);
+	
+	// Give FLDIGI time to switch modems.
+	MilliSleep(150);
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 void send_clear_tx(void)
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
+
 	try {
 		XmlRpcValue res;
 		execute(text_clear_tx, 0, res);
@@ -187,12 +191,14 @@ void send_clear_tx(void)
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
 	update_interval = XMLRPC_UPDATE_AFTER_WRITE;
-	pthread_mutex_unlock(&mutex_xmlrpc);
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 void send_clear_rx(void)
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		XmlRpcValue res;
 		execute(text_clear_rx, 0, res);
@@ -200,12 +206,14 @@ void send_clear_rx(void)
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
 	update_interval = XMLRPC_UPDATE_AFTER_WRITE;
-	pthread_mutex_unlock(&mutex_xmlrpc);
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 void send_report(std::string report)
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		XmlRpcValue res, xml_str = report;
 		execute(text_clear_tx, 0, res);
@@ -214,12 +222,14 @@ void send_report(std::string report)
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
 	update_interval = XMLRPC_UPDATE_AFTER_WRITE;
-	pthread_mutex_unlock(&mutex_xmlrpc);
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 void send_tx(void)
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		XmlRpcValue res;
 		execute(main_tx, 0, res);
@@ -227,12 +237,14 @@ void send_tx(void)
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
 	update_interval = XMLRPC_UPDATE_AFTER_WRITE;
-	pthread_mutex_unlock(&mutex_xmlrpc);
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 void send_rx(void)
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		XmlRpcValue res;
 		execute(main_rx, 0, res);
@@ -240,12 +252,14 @@ void send_rx(void)
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
 	update_interval = XMLRPC_UPDATE_AFTER_WRITE;
-	pthread_mutex_unlock(&mutex_xmlrpc);
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 void set_rsid(void)
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		XmlRpcValue res;
 		execute(main_set_rsid, 0, res);
@@ -253,12 +267,14 @@ void set_rsid(void)
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
 	update_interval = XMLRPC_UPDATE_AFTER_WRITE;
-	pthread_mutex_unlock(&mutex_xmlrpc);
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 void send_abort(void)
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		XmlRpcValue res;
 		execute(main_abort, 0, res);
@@ -266,12 +282,14 @@ void send_abort(void)
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
 	update_interval = XMLRPC_UPDATE_AFTER_WRITE;
-	pthread_mutex_unlock(&mutex_xmlrpc);
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 void send_tune(void)
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		XmlRpcValue res;
 		execute(main_tune, 0, res);
@@ -279,16 +297,18 @@ void send_tune(void)
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
 	update_interval = XMLRPC_UPDATE_AFTER_WRITE;
-	pthread_mutex_unlock(&mutex_xmlrpc);
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 std::string get_tx_timing(std::string data)
 {
 	XmlRpcValue status;
 	XmlRpcValue xmlData((void *)data.c_str(), data.size());
 	static std::string response;
 
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		execute(main_get_tx_timing, xmlData, status);
 		std::string resp = status;
@@ -297,14 +317,16 @@ std::string get_tx_timing(std::string data)
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
 	update_interval = XMLRPC_UPDATE_AFTER_WRITE;
-	pthread_mutex_unlock(&mutex_xmlrpc);
 
 	return response;
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 std::string get_char_timing(int character)
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 
 	XmlRpcValue status;
 	static std::string response;
@@ -327,15 +349,17 @@ std::string get_char_timing(int character)
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
 
-	update_interval = XMLRPC_UPDATE_AFTER_WRITE * 2;
-	pthread_mutex_unlock(&mutex_xmlrpc);
+	update_interval = XMLRPC_UPDATE_AFTER_WRITE;
 
 	return response;
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 void enable_arq(void)
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		XmlRpcValue res;
 		execute(io_enable_arq, 0, res);
@@ -343,12 +367,11 @@ void enable_arq(void)
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
 	update_interval = XMLRPC_UPDATE_AFTER_WRITE;
-	pthread_mutex_unlock(&mutex_xmlrpc);
 }
 
 void enable_kiss(void)
 {
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		XmlRpcValue res;
 		execute(io_enable_kiss, 0, res);
@@ -356,35 +379,73 @@ void enable_kiss(void)
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
 	update_interval = XMLRPC_UPDATE_AFTER_WRITE;
-	pthread_mutex_unlock(&mutex_xmlrpc);
 }
 
 // --------------------------------------------------------------------
 // receive functions
 // --------------------------------------------------------------------
 
+/** ********************************************************
+ *
+ ***********************************************************/
+void set_offline_state(void)
+{
+	modem_list_received = 0;
+	fldigi_state = FLDIGI_OFFLINE;
+}
+
+/** ********************************************************
+ * fldigi_online()
+ * returns either FLDIGI_OFFLINE or FLDIGI_ONLINE
+ * depending on whether the get version query receives a
+ * response from the target fldigi instance
+ ***********************************************************/
+int fldigi_online()
+{
+	XmlRpcValue status;
+	XmlRpcValue query;
+
+	guard_lock lock(&mutex_xmlrpc);
+	try {
+		execute(fldigi_get_version, query, status);
+		fldigi_state |= FLDIGI_XMLRPC_ONLINE;
+	} catch (const XmlRpc::XmlRpcException& e) {
+		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
+		set_offline_state();
+	}
+
+	return fldigi_state;
+}
+
+/** ********************************************************
+ *
+ ***********************************************************/
 std::string get_io_mode(void)
 {
 	XmlRpcValue status;
 	XmlRpcValue query;
 	static std::string response;
 
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		execute(io_in_use, query, status);
 		std::string resp = status;
 		response = resp;
+		fldigi_state |= FLDIGI_XMLRPC_ONLINE;
 	} catch (const XmlRpc::XmlRpcException& e) {
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 		response = "NIL";
+		set_offline_state();
 	}
-	pthread_mutex_unlock(&mutex_xmlrpc);
 
 	xmlrpc_timeout = DEFAULT_XMLRPC_TIMEOUT;
 
 	return response;
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 static void set_combo(void *str)
 {
 	std::string s = (char *)str;
@@ -399,13 +460,16 @@ static void set_combo(void *str)
 	}
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 std::string get_rsid_state(void)
 {
 	XmlRpcValue status;
 	XmlRpcValue query;
 	static std::string response;
 
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		execute(main_get_rsid, query, status);
 		std::string resp = status;
@@ -413,38 +477,61 @@ std::string get_rsid_state(void)
 	} catch (const XmlRpc::XmlRpcException& e) {
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
-	pthread_mutex_unlock(&mutex_xmlrpc);
 
 	return response;
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
+void connected_to_fldigi(void *state)
+{
+	if (state) {
+		box_not_connected->hide();
+		box_connected->show();
+	} else {
+		box_not_connected->show();
+		box_connected->hide();
+	}
+	box_not_connected->redraw();
+	box_connected->redraw();
+}
+
+/** ********************************************************
+ *
+ ***********************************************************/
 std::string get_trx_state()
 {
 	XmlRpcValue status;
 	XmlRpcValue query;
 	static std::string response;
 
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		execute(main_get_trx_state, query, status);
 		std::string resp = status;
 		response = resp;
+		fldigi_state |= FLDIGI_XMLRPC_ONLINE;
 	} catch (const XmlRpc::XmlRpcException& e) {
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 		response = "ABORT";
+		// This function is used to test if FLDIGI is off/on line.
+		set_offline_state();
 	}
-	pthread_mutex_unlock(&mutex_xmlrpc);
 
 	return response;
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 std::string get_char_rates()
 {
 	XmlRpcValue status;
 	XmlRpcValue query;
 	static std::string response;
 
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		execute(main_get_char_rates, query, status);
 		std::string resp = status;
@@ -452,85 +539,101 @@ std::string get_char_rates()
 	} catch (const XmlRpc::XmlRpcException& e) {
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
-	pthread_mutex_unlock(&mutex_xmlrpc);
 
 	return response;
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 static void get_fldigi_modem()
 {
 	if (!progStatus.sync_mode_fldigi_flamp) return;
-
+	
 	XmlRpcValue status;
 	XmlRpcValue query;
 	static std::string response;
 
-	pthread_mutex_lock(&mutex_xmlrpc);
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
 		execute(modem_get_name, query, status);
 		std::string resp = status;
 		response = resp;
+
 		if (!response.empty()) {
 			Fl::awake(set_combo, (void *)response.c_str());
 		}
 	} catch (const XmlRpc::XmlRpcException& e) {
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 	}
-	pthread_mutex_unlock(&mutex_xmlrpc);
 }
 
-bool fldigi_online = false;
-bool logerr = true;
-
+/** ********************************************************
+ *
+ ***********************************************************/
 static void get_fldigi_modems()
 {
-	XmlRpcValue status, query;
+	XmlRpcValue status;
+	XmlRpcValue query;
+	static std::string response;
+	static std::string tmp;
+	static std::string fldigi_modes;
 
-	pthread_mutex_lock(&mutex_xmlrpc);
+	fldigi_modes.clear();
+
+	guard_lock xmlrpc_client(&mutex_xmlrpc);
 	try {
-		std::string fldigi_modes("");
-		execute(modem_get_names, query, status);
+
+		execute(modem_get_io_names, query, status);
+
 		for (int i = 0; i < status.size(); i++) {
-			fldigi_modes.append((std::string)status[i]).append("|");
+			tmp = (std::string)status[i];
+			fldigi_modes.append(tmp).append("|");
 		}
+
 		update_cbo_modes(fldigi_modes);
-		fldigi_online = true;
-		logerr = true;
+
+		modem_list_received = true;
+
 	} catch (const XmlRpc::XmlRpcException& e) {
 		LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
+		if(e.getMessage().find("expected an array") == std::string::npos)
+			set_offline_state();
 	}
-	pthread_mutex_unlock(&mutex_xmlrpc);
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 void * xmlrpc_loop(void *d)
 {
-	fldigi_online = false;
+	if (!client) open_xmlrpc();
+	size_t state = 0;
+	static size_t old_state = FLDIGI_OFFLINE;
+	
 	for (;;) {
 		try {
-			if (fldigi_online)
+			state = (fldigi_online() & FLDIGI_XMLRPC_ONLINE);
+			
+			if (state && !modem_list_received)
+				get_fldigi_modems();
+			else if (state)
 				get_fldigi_modem();
 			else
-				get_fldigi_modems();
+				set_offline_state();
+				
+			state = fldigi_state == FLDIGI_ONLINE ? 1 : 0;
+
+			if(old_state != state) 
+				Fl::awake(connected_to_fldigi, (void *)state);
+
+			old_state = state;
+			
 		} catch (const XmlRpc::XmlRpcException& e) {
-			if (logerr) {
-				LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
-				logerr = false;
-			}
-
-			pthread_mutex_lock(&mutex_xmlrpc);
-			fldigi_online = false;
-			update_interval = XMLRPC_RETRY_INTERVAL;
-			pthread_mutex_unlock(&mutex_xmlrpc);
-
+			LOG_ERROR("%s xmlrpc_errno = %d", e.getMessage().c_str(), xmlrpc_errno);
 		}
 
-		MilliSleep(update_interval);
-
-		pthread_mutex_lock(&mutex_xmlrpc);
-		if (update_interval != XMLRPC_UPDATE_INTERVAL)
-			update_interval = XMLRPC_UPDATE_INTERVAL;
-		pthread_mutex_unlock(&mutex_xmlrpc);
-
+		MilliSleep(XMLRPC_UPDATE_INTERVAL);
 	}
 	return NULL;
 }
