@@ -62,6 +62,7 @@
 #include "threads.h"
 #include "flamp.h"
 #include "flamp_dialog.h"
+#include "dialogs.h"
 #include "xml_io.h"
 #include "ztimer.h"
 #include "fileselect.h"
@@ -274,6 +275,9 @@ time_t parse_repeat_times(bool delete_flag, unsigned int zt)
 }
 #else
 
+/** ********************************************************
+ *
+ ***********************************************************/
 char *skip_spaces(char *cPtr, char *ePtr)
 {
 	if(!cPtr || !ePtr)
@@ -293,6 +297,9 @@ char *skip_spaces(char *cPtr, char *ePtr)
 	return cPtr;
 }
 
+/** ********************************************************
+ *
+ ***********************************************************/
 char *skip_numbers(char *cPtr, char *ePtr)
 {
 	if(!cPtr || !ePtr)
@@ -435,6 +442,7 @@ time_t time_check(void)
  * \param tv struct timeval storage by reference.
  * \return void
  ***********************************************************/
+ /*
 void execute_ztimer(bool flag, struct timeval &tv)
 {
 	pthread_mutex_lock(&mutex_watch_dog);
@@ -450,6 +458,7 @@ void execute_ztimer(bool flag, struct timeval &tv)
 
 	pthread_mutex_unlock(&mutex_watch_dog);
 }
+*/
 
 /** ********************************************************
  * fldigi was closed before flamp ... abort
@@ -457,16 +466,58 @@ void execute_ztimer(bool flag, struct timeval &tv)
 void abort_flamp(void *)
 {
 	fl_alert2(_("fldigi off line"));
-	close_ops();
-	exit(0);
+	clean_shutdown();
 }
 
+//#define TEST_INTERVAL 2  // CHECK every nn seconds
+
+/** ********************************************************
+ *
+ ***********************************************************/
+extern size_t fldigi_state;
+
+void connect_to_fldigi(void *)
+{
+	guard_lock fio(&mutex_file_io);
+	guard_lock lock(&mutex_xmlrpc);
+
+	try {
+		if (!tcpip && (fldigi_state != FLDIGI_ONLINE)) {
+			tcpip = new Socket (*localaddr);
+			tcpip->set_timeout(0.01);
+		}
+		tcpip->connect();
+
+		fldigi_state |= FLDIGI_STREAM_ONLINE;
+		
+		LOG_DEBUG("Connected to %d", tcpip->fd());
+	}
+	catch (const SocketException& e) {
+		if (tcpip) tcpip->close();
+		delete tcpip;
+		tcpip = 0;
+		file_io_errno = errno;
+		if(e.error() != 0) {
+			fldigi_state = FLDIGI_OFFLINE;
+			LOG_ERROR("%s %d", e.what(), file_io_errno);
+		}
+	}
+}
+
+/** ********************************************************
+ *
+ ***********************************************************/
+extern size_t fldigi_state;
+
 void fldigi_ok()
-{	std::string test = get_io_mode();
-	if (test == "NIL" || test.empty()) {
-		Fl::remove_timeout(ztimer);
-		abort_flamp(0);
-//		Fl::awake(abort_flamp);
+{
+	std::string test = get_io_mode();
+	
+	if (test == "ARQ") {
+		if(fldigi_state == FLDIGI_XMLRPC_ONLINE)
+			connect_to_fldigi(NULL);
+	} else if(test == "KISS") {
+		LOG_INFO("FLDIGI I/O Setting are set to KISS, Requires ARQ.");
 	}
 }
 
@@ -482,6 +533,7 @@ void fldigi_ok()
  * \return void* null unused. Required for pthread call.
  *
  ***********************************************************/
+/*
 void *watch_dog_loop(void *p)
 {
 	time_t current_time = 0;
@@ -506,6 +558,17 @@ void *watch_dog_loop(void *p)
 
 	return (void *)0;
 }
+*/
+
+void watch_dog_check()
+{
+	time_t current_time = time_check();
+	double diff_time = (double) (watch_dog_seconds - current_time);
+	if (diff_time > 10.0 || (diff_time < -10.0)) {
+// reset the clock
+//		execute_ztimer(false, tv);
+	}
+}
 
 /** ********************************************************
  * \brief FLAMP event timer.
@@ -513,7 +576,7 @@ void *watch_dog_loop(void *p)
  * count down timer is reset.
  * \return void (nothing)
  ***********************************************************/
-void ztimer(void* first_call)
+void ztimer() //void* first_call)
 {
 	struct timeval tv;
 	static bool tx_toggle = false;
@@ -524,16 +587,9 @@ void ztimer(void* first_call)
 	static std::string tx_duration;
 	bool flag = false;
 
-	if (first_call) {
-		flag = true;
-		execute_ztimer(flag, tv);
-	} else {
-		execute_ztimer(flag, tv);
-	}
-
-	if(generate_time_table) {
-		return; // No Events Allow in Time Table Generation Mode.
-	}
+	pthread_mutex_lock(&mutex_watch_dog);
+	gettimeofday(&tv, NULL);
+	pthread_mutex_unlock(&mutex_watch_dog);
 
 	struct tm tm;
 	time_t t_temp;
@@ -549,12 +605,15 @@ void ztimer(void* first_call)
 	if (!strftime(szoutTimeValue, sizeof(szoutTimeValue), "%H:%M:%S", &tm))
 		memset(szoutTimeValue, 0, sizeof(szoutTimeValue));
 
-	watch_dog_seconds = time_check();
+//	int tc = atoi(&sztime[4]);
+//	if (tc % TEST_INTERVAL == 0) {
+//		fldigi_ok();
+//	}
 
-	int tc = atoi(&sztime[4]);
-	if (tc % 30 == 0) { // every 30 seconds
-		fldigi_ok();
-	}
+	if (generate_time_table)
+		return; // No Events Allow in Time Table Generation Mode.
+
+	watch_dog_seconds = time_check();
 
 	tx_state = get_trx_state();
 	if((tx_state == "RX"))
@@ -658,3 +717,82 @@ void ztimer(void* first_call)
 		}
 	}
 }
+
+//======================================================================
+// TOD Thread loop
+//======================================================================
+
+static pthread_t TOD_thread;
+bool TOD_enabled = false;
+bool TOD_exit = false;
+
+void *TOD_loop(void *args)
+{
+//	SET_THREAD_ID(TOD_TID);
+#define LOOP  100
+	int cnt = 0;
+	int wdcnt = 0;
+	int fldigi_cnt = 0;
+
+	while(1) {
+		if (TOD_exit) break;
+
+		if (++cnt == 10) { // every second
+//			guard_lock tmlock(&time_mutex);
+			ztimer();
+			cnt = 0;
+		}
+		if (++fldigi_cnt == 20) {
+			fldigi_ok();
+			fldigi_cnt = 0;
+		}
+		if (++wdcnt == 100) { // every 10 seconds
+			watch_dog_check();
+			wdcnt = 0;
+		}
+
+		MilliSleep(LOOP);
+	}
+
+// exit the TOD thread
+//	SET_THREAD_CANCEL();
+	return NULL;
+}
+
+//======================================================================
+//
+//======================================================================
+void TOD_init()
+{
+	if (TOD_enabled)
+		return;
+
+	TOD_exit = false;
+
+	if (pthread_create(&TOD_thread, NULL, TOD_loop, NULL) < 0) {
+		LOG_ERROR("%s", "pthread_create failed");
+		return;
+	}
+
+	LOG_INFO("%s", "Time Of Day thread started");
+
+	TOD_enabled = true;
+}
+
+//======================================================================
+//
+//======================================================================
+void TOD_close()
+{
+	if (!TOD_enabled) return;
+
+	TOD_exit = true;
+
+	pthread_join(TOD_thread, NULL);
+
+	TOD_enabled = false;
+
+	LOG_INFO("%s", "Time Of Day thread terminated. ");
+
+}
+
